@@ -638,7 +638,7 @@ class ModulesCache(object):
         mani_hash = get_hash(MANIFEST_FILE().read_text())
         hash = get_hash(f"{hash_git}{mani_hash}")
 
-        file = Path(os.path.expanduser(f"~/.local/cache/wodoo/modules/{hash}.bin"))
+        file = Path(os.path.expanduser(f"~/.local/cache/wodoo/modules/{hash}.v3.bin"))
         file.parent.mkdir(exist_ok=True, parents=True)
         try_to_set_owner(whoami(), file.parent.parent)
         return file
@@ -689,7 +689,12 @@ class Modules(object):
         modules = {}
         all_manifests = get_all_manifests()
         for m in all_manifests:
-            modules[m.parent.name] = Module(m)
+            module = Module(m)
+            module.manifest_dict.get("just read manifest")
+            modules[m.parent.name] = module
+
+        for module in modules.values():
+            Modules._get_module_dependency_tree(modules, module)
 
         # if directory is clear, we may cache
         return modules
@@ -739,6 +744,10 @@ class Modules(object):
         return modules
 
     def get_module_dependency_tree(self, module):
+        return self._get_module_dependency_tree(self.modules, module)
+
+    @classmethod
+    def _get_module_dependency_tree(cls, modules, module):
         """
         Dict of dicts
 
@@ -757,7 +766,7 @@ class Modules(object):
                 if dep == "base":
                     data[mod.name][dep] = {}
                     continue
-                dep_mod = [x for x in self.modules.values() if x.name == dep]
+                dep_mod = [x for x in modules.values() if x.name == dep]
                 try:
                     dep_mod = dep_mod[0]
                 except IndexError:
@@ -776,8 +785,10 @@ class Modules(object):
                     data[mod.name][dep] = {}
                     append_deps(dep_mod, data[mod.name][dep])
 
-        append_deps(module, result)
-        return result
+        if module._dep_tree is None:
+            append_deps(module, result)
+            module._dep_tree = result
+        return module._dep_tree
 
     def get_all_modules_installed_by_manifest(self):
         all_modules = set()
@@ -822,7 +833,7 @@ class Modules(object):
 
     def get_all_auto_install_modules(self):
         auto_install_modules = []
-        for module in Modules().modules:
+        for module in sorted(Modules().modules):
             try:
                 module = Module.get_by_name(module)
             except NotInAddonsPath:
@@ -847,7 +858,7 @@ class Modules(object):
                 installed_dependencies = set(
                     [
                         x
-                        for x in dependencies
+                        for x in sorted(dependencies)
                         if x.manifest_dict.get("auto_install") or x in complete_modules
                     ]
                 )
@@ -857,7 +868,7 @@ class Modules(object):
                     if all(x in module_list for x in dependencies):
                         yield auto_install_module
 
-        modules = self.get_all_auto_install_modules()
+        modules = list(sorted(self.get_all_auto_install_modules()))
         while True:
             before = list(sorted(set(map(lambda x: x.name, modules))))
             modules = list(_get(modules))
@@ -1041,6 +1052,7 @@ class Module(object):
         self.name = self._manifest_path.parent.name
         self.path = self._manifest_path.parent
         os.chdir(remember_cwd)
+        self._dep_tree = None
 
     @property
     def manifest_path(self):
@@ -1083,6 +1095,7 @@ class Module(object):
 
     @property
     def hash(self):
+        import pudb;pudb.set_trace()
         from .tools import get_directory_hash
 
         return get_directory_hash(self.path)
@@ -1101,11 +1114,12 @@ class Module(object):
 
     @classmethod
     def _get_by_name(cls, name):
-
         try:
-            ModulesCache.get(name)
+            res = ModulesCache.get(name)
         except IndexError:
             pass
+        else:
+            return res
 
         from .odoo_config import get_odoo_addons_paths
 
